Method: FileUtils2#mv
- Defined in:
- lib/fileutils2.rb
#mv(src, dest, options = {}) ⇒ Object Also known as: move
Options: force noop verbose
Moves file(s) src to dest. If file and dest exist on the different disk partition, the file is copied then the original file is removed.
FileUtils.mv 'badname.rb', 'goodname.rb'
FileUtils.mv 'stuff.rb', '/notexist/lib/ruby', :force => true # no error
FileUtils.mv %w(junk.txt dust.txt), '/home/aamine/.trash/'
FileUtils.mv Dir.glob('test*.rb'), 'test', :noop => true, :verbose => true
589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/fileutils2.rb', line 589 def mv(src, dest, = {}) , OPT_TABLE['mv'] "mv#{[:force] ? ' -f' : ''} #{[src,dest].flatten.join ' '}" if [:verbose] return if [:noop] fu_each_src_dest(src, dest) do |s, d| destent = Entry_.new(d, nil, true) begin if destent.exist? if destent.directory? raise Errno::EEXIST, dest else destent.remove_file if rename_cannot_overwrite_file? end end begin File.rename s, d rescue Errno::EXDEV copy_entry s, d, true if [:secure] remove_entry_secure s, [:force] else remove_entry s, [:force] end end rescue SystemCallError raise unless [:force] end end end |